@@ -1,8 +1,13 @@
 from .keycloak import Keycloak
 from . import poolparty
+from . import jenkins
+
 
 from functools import update_wrapper, partial
 from configparser import ConfigParser
+import subprocess
+import os
+import appdirs
 import click
 
 @click.group()
@@ -10,6 +15,11 @@ def cli():
     """The venerable P3D command line utils"""
     ...
 
+@cli.group()
+def jk():
+    """Jenkins commands"""
+    ...
+
 @cli.group()
 def pp():
     """PoolParty commands"""
@@ -27,7 +37,7 @@ def kc_adm_command(func):
     @click.option("--password", help="The password")
     @click.option("--user_realm_name", help="The realm the user is in")
     @click.option("--realm_name", help="The realm the mappers should be added to")
-    @click.option("--auth_config", type=click.Path('r'), help="Read KC authorization from a config file")
+    @click.option("--auth_config", type=click.Path(exists=True, dir_okay=False, readable=True), help="Read KC authorization from a config file")
     @click.option("--auth", help="Read KC authorization from a config file")
     @click.pass_context
     def inner(ctx, *args, **kwargs):
@@ -92,34 +102,97 @@ def add_mappers(ctx, json):
     kc = ctx.obj['kc']
     kc.import_mappers(json)
 
-
 @pp.command()
 @click.argument("clear_text")
-@click.argument("password")
-@click.argument("salt")
-@click.argument("strength", type=click.INT)
+@click.option("--password", prompt=True, help="The password used for encryption")
+@click.option("--salt", prompt=True, help="The salt used for encryption")
+@click.option("--strength", prompt=True, type=click.INT, help="The strength used for encryption")
 def encrypt(clear_text: str, password: str, salt: str, strength: int):
     """Encrypt clear text with poolparty encryption
 
     The settings for PASSWORD, SALT and STRENGTH can usually be found in the
     poolparty.properties file.
+
+    Leave out any of option parameters (--password, --salt, --strengh) to get an
+    interactive prompt.
     """
     secret = poolparty.encrypt(clear_text, password, salt, strength)
     print(secret)
 
 @pp.command()
 @click.argument("secret")
-@click.argument("password")
-@click.argument("salt")
-@click.argument("strength", type=click.INT)
+@click.option("--password", prompt=True, help="The password used for decryption")
+@click.option("--salt", prompt=True, help="The salt used for decryption")
+@click.option("--strength", prompt=True, type=click.INT, help="The strength used for decryption")
 def decrypt(secret: str, password: str, salt: str, strength: int):
     """Decrypt secret text with poolparty encryption
 
     The settings for PASSWORD, SALT and STRENGTH can usually be found in the
     poolparty.properties file.
+
+    Leave out any of the option parameters (--password, --salt, --strengh) to get an interactive prompt.
     """
     clear = poolparty.decrypt(secret, password, salt, strength)
     print(clear)
 
+@jk.command()
+@click.option("--branch", help="The branch to build")
+@click.option('--no-autodetect', type=click.BOOL, is_flag=True, default=False, help="Disable autodetection of branch in a git repository")
+@click.option('--api-user', type=click.STRING, help="Jenkins API user (your username)")
+@click.option('--api-key', type=click.STRING, help="Jenkins API key (generate in Jenkins)")
+def build(branch: str, no_autodetect: bool, api_key: str, api_user: str):
+    """Run the PoolParty build
+
+    Per default (and outside a git repository) builds the `develop` branch of
+    PoolParty.
+
+    When inside a git repository `p3do` will automatically detect the current
+    branch and build it. This behavior can be disabled with --no-autodetect.
+
+    The branch to build can be specified via --branch (note that this implies
+    --no-autodetect inside a git repository).
+    """
+
+    if not api_key:
+        cache_dir = appdirs.user_cache_dir("p3do")
+        os.makedirs(cache_dir, exist_ok=True)
+        jk_key = os.path.join(cache_dir, "jk_key")
+
+        try:
+            with open(jk_key, 'r') as f:
+                api_key = f.read()
+        except:
+            api_key = click.prompt("Jenkins API Key")
+            with open(jk_key, 'w') as f:
+                f.write(api_key)
+
+    if not api_user:
+        cache_dir = appdirs.user_cache_dir("p3do")
+        os.makedirs(cache_dir, exist_ok=True)
+        jk_user = os.path.join(cache_dir, "jk_user")
+
+        try:
+            with open(jk_user, 'r') as f:
+                api_user = f.read()
+        except:
+            api_user = click.prompt("Jenkins API User")
+            with open(jk_user, 'w') as f:
+                f.write(api_user)
+
+    if not branch and no_autodetect:
+        branch = "develop"
+    elif not branch and not no_autodetect:
+        res = subprocess.run(["git", "rev-parse", "--abbrev-ref", "HEAD"], capture_output=True)
+        if res.returncode == 0:
+            print(res)
+            branch = res.stdout.decode('utf-8').strip(" \n")
+        else:
+            print(res)
+            branch = "develop"
+    # else: branch given
+
+    jenkins.run_build("P3D-BUILD", branch, api_user, api_key)
+
+
 if __name__ == "__main__":
     cli()
