@@ -1,5 +1,6 @@
 import json
-from keycloak import KeycloakAdmin
+from fabric import Connection
+import keycloak as kc
 
 
 class Keycloak:
@@ -11,7 +12,7 @@ class Keycloak:
         self.realm_name = realm_name
 
         print(f"{server}")
-        self.keycloak_admin = KeycloakAdmin(server_url=server,
+        self.keycloak_admin = kc.KeycloakAdmin(server_url=server,
                                             username=username,
                                             password=password,
                                             user_realm_name=user_realm_name,
@@ -23,3 +24,15 @@ class Keycloak:
 
         for mapper in mappers:
             self.keycloak_admin.add_mapper_to_idp(mapper["identityProviderAlias"], mapper)
+
+def encrypt_ssh(host, poolparty):
+    con = Connection(host)
+    print(f"Connected to {host}: {con}")
+    res = con.run("hostname")
+    print(f"Hostname: {res}")
+    res = con.run("sudo su poolparty")
+    print(f"Sudo: {res}")
+    con.run(f"cd {poolparty}")
+    con.run(f"cd config")
+    props = con.run(f"cat poolparty.properties").stdout.strip()
+    print(props)
